@@ -403,15 +403,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 35
-#define MYSQL_VERSION_EXTRA "-ndb-7.5.23"
+#define MYSQL_VERSION_PATCH 36
+#define MYSQL_VERSION_EXTRA "-ndb-7.5.24"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.35-ndb-7.5.23"
+#define PACKAGE_STRING "MySQL Server 5.7.36-ndb-7.5.24"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.35-ndb-7.5.23"
-#define VERSION "5.7.35-ndb-7.5.23"
+#define PACKAGE_VERSION "5.7.36-ndb-7.5.24"
+#define VERSION "5.7.36-ndb-7.5.24"
 #define PROTOCOL_VERSION 10
 
 /*
@@ -438,10 +438,6 @@
 #define HAVE_FCNTL_H 1
 #define HAVE_GETADDRINFO 1
 #define HAVE_INTTYPES_H 1
-/* libevent's select.c is not Windows compatible */
-#ifndef _WIN32
-#define HAVE_SELECT 1
-#endif
 #define HAVE_SIGNAL_H 1
 #define HAVE_STDARG_H 1
 #define HAVE_STDINT_H 1
